@@ -16,7 +16,8 @@ class ImpressaoRelatorio(View):
         return {
             'object_list': self.object_list,
             'titulo': self.titulo,
-            'user': self.request.user
+            'user': self.request.user,
+            'kwargs': self._kwargs,
         }
 
     def post(self, *args, **kwargs):
